[PATCH 11/18] drm/i915/dpll: Introduce new hook in intel_dpll_funcs

Suraj Kandpal suraj.kandpal at intel.com
Mon Apr 7 08:16:47 UTC 2025


Introduce disable hook to disable individual dpll which is to
be used by DISPLAY_VER() >= 14.

--v2
-Rename intel_global_dpll to intel_dpll_global [Jani/Ville]

Signed-off-by: Suraj Kandpal <suraj.kandpal at intel.com>
---
 drivers/gpu/drm/i915/display/intel_dpll_mgr.c | 8 +++++++-
 1 file changed, 7 insertions(+), 1 deletion(-)

diff --git a/drivers/gpu/drm/i915/display/intel_dpll_mgr.c b/drivers/gpu/drm/i915/display/intel_dpll_mgr.c
index 2106d3c54190..886e307ea5ac 100644
--- a/drivers/gpu/drm/i915/display/intel_dpll_mgr.c
+++ b/drivers/gpu/drm/i915/display/intel_dpll_mgr.c
@@ -70,7 +70,13 @@ struct intel_dpll_funcs {
 		       struct intel_encoder *encoder);
 
 	/*
-	 * Hook for disabling the shared pll, called from _intel_disable_shared_dpll()
+	 * Hook for disabling the individual pll, used from DISPLAY_VER() >= 14
+	 */
+	void (*disable)(struct intel_display *display,
+			struct intel_dpll *pll);
+
+	/*
+	 * Hook for disabling the shared pll, called from intel_disable_global_dpll()
 	 * only when it is safe to disable the pll, i.e., there are no more
 	 * tracked users for it.
 	 */
-- 
2.34.1



More information about the Intel-gfx mailing list